<?php
namespace UCC\UCCPlugin\Block\Checkout;

use Magento\Checkout\Model\Session;
use Magento\Framework\View\Element\Template\Context;
use Magento\Sales\Model\Order;
use Magento\Sales\Model\OrderFactory;

class Success extends \Magento\Checkout\Block\Success
{
    /**
     * @var Session
     */
    private $checkoutSession;

    /**
     * @var Order
     */
    private $order;

    /**
     * @var OrderFactory
     */
    private $orderFactory;

    /**
     * Success constructor.
     * @param Context $context
     * @param OrderFactory $orderFactory
     * @param Session $session
     * @param array $data
     */
    public function __construct(
        Context $context,
        OrderFactory $orderFactory,
        Session $session,
        array $data = []
    ) {
        $this->checkoutSession = $session;
        $this->orderFactory = $orderFactory;
        $this->order = $this->checkoutSession->getLastRealOrder();

        parent::__construct($context, $orderFactory, $data);
    }

    /**
     * @return array
     */
    public function getProductList() {
        $products = [];
        foreach ($this->order->getAllVisibleItems() as $product) {
            try {
                $products[] = [
                    'id' => $product->getProduct()->getCustomAttribute('ucc_gtin_code')->getValue(),
                    'price' => number_format(
                        $product->getBasePrice() + ($product->getBaseTaxAmount() / (int)$product->getQtyOrdered()),
                        2
                    ),
                    'qty' => (int)$product->getQtyOrdered(),
                    'baseId' => $product->getProduct()->getId()
                ];
            } catch (\Exception $exception) {
                $products[0]['qty'] = 'not completed';
            }
        }

        return $products;
    }
}
